@@ -3,9 +3,9 @@ package Jifty::DBI::Filter::DateTime;
 use warnings;
 use strict;
 
-use base qw(Jifty::DBI::Filter);
-use DateTime                   ();
-use DateTime::Format::Strptime ();
+use base qw|Jifty::DBI::Filter|;
+use DateTime                  ();
+use DateTime::Format::ISO8601 ();
 
 =head1 NAME
 
@@ -13,14 +13,14 @@ Jifty::DBI::Filter::DateTime - DateTime object wrapper around date columns
 
 =head1 DESCRIPTION
 
-This filter allow you to work with DateTime objects instead of
-plain text dates.
+This filter allow you to work with DateTime objects instead of plain
+text dates.
 
 =head2 encode
 
 If value is DateTime object then converts it into ISO format
-C<YYYY-MM-DD hh:mm:ss>. Does nothing if value is not defined
-or string.
+C<YYYY-MM-DD hh:mm:ss>. Does nothing if value is not defined or
+string.
 
 =cut
 
@@ -39,8 +39,8 @@ sub encode {
 
 =head2 decode
 
-If value is defined then converts it into DateTime object otherwise
-do nothing.
+If value is defined then converts it into DateTime object otherwise do
+nothing.
 
 =cut
 
@@ -56,9 +56,11 @@ sub decode {
 #    server time_zone, by default ISO
 # other DBs may have own formats(Interbase for example can be forced to use special format)
 # but we need Jifty::DBI::Handle here to get DB type
-    my $parser
-        = DateTime::Format::Strptime->new( pattern => '%Y-%m-%d %H:%M:%S', );
-    my $dt = $parser->parse_datetime($$value_ref);
+
+    my $str = $$value_ref;
+    $str =~ s/ /T/;
+
+    my $dt = DateTime::Format::ISO8601->parse_datetime($str);
     if ($dt) {
         $$value_ref = $dt;
     } else {
